#
# spec file for package selene
#
# Copyright (c) 2020 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


Name:           selene
Version:        17.7
Release:        150500.2.pm.6
Summary:        GUI audio-video converter for GNU/Linux
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://github.com/teejee2008/selene
Source:         https://github.com/teejee2008/selene/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE selene-fix-makefile.patch sor.alexei@meowr.ru -- Various Makefile fixes.
Patch0:         %{name}-fix-makefile.patch
# PATCH-FIX-UPSTREAM selene-fix-abstract.patch
Patch1:         %{name}-fix-abstract.patch
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
Requires:       coreutils
Requires:       ffmpeg
Requires:       lame
Requires:       mediainfo
Requires:       mkvtoolnix
Requires:       mpv
Requires:       rsync
Requires:       vorbis-tools
Requires:       x264
Recommends:     %{name}-lang
Recommends:     gpac
Recommends:     opus-tools
Recommends:     sox
Recommends:     vpx-tools
Recommends:     x265

%description
Utility for converting audio and video files to OGV, MKV, MP4,
WebM, Opus, AAC, FLAC, MP3, and WAV formats. Provides a simple GUI
for converting files to popular formats with powerful command-line
options for automated/unattended encoding.

%lang_package

%prep
%autosetup -p1
# Use ffmpeg instead of libav in scripts.
find src/share/selene/scripts/ -type f | while read file; do
    sed -i 's/avconv/ffmpeg/g' "$file"
done

%build
make %{?_smp_mflags} V=1 \
  CFLAGS="%{optflags}"

%install
%make_install \
  prefix=%{_prefix}

# Remove the uninstaller.
rm %{buildroot}%{_bindir}/%{name}-uninstall

%find_lang %{name}
%suse_update_desktop_file -r %{name} AudioVideo AudioVideoEditing
%fdupes %{buildroot}%{_datadir}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%files lang -f %{name}.lang

%changelog
* Mon Apr 20 2020 Luigi Baldoni <aloisio@gmx.com>
- Add selene-fix-abstract.patch to fix build with recent versions
  of vala
* Thu Mar 29 2018 sor.alexei@meowr.ru
- Update to version 17.7:
  * Add support for OPUS in WebM, MKV and OGG containers.
  * Add audio tag support for Fraunhoffer AAC encoding.
  * Use mpv for playing media instead of an internal player.
  * MediaPlayer: Centre screen and show the file name in header bar.
  * Update translations.
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 17.4.2 (changes since 16.9):
  * Fix issues with newer GTK+ versions.
  * Use GtkStackSwitcher in AppSettings window.
  * Use GtkSidebar in encoder settings window.
  * Subs: Add support for muxing ASS subs in MKV.
  * AppSettings: Show OK button instead of Save & Cancel.
  * AppSettings: Save settings if window is closed directly.
  * Remove dependency on realpath.
  * Fix Progress column hidden during encoding in list view.
  * Add Dutch translation.
- Rebase selene-fix-makefile.patch.
* Fri Oct 14 2016 sor.alexei@meowr.ru
- Update to version 16.9:
  * Fix encoding failing when ffmpeg fails to detect file encoding
    of the SRT file.
  * Fix icon in 'Add Files..' menu not being sized correctly.
  * Add an option to encode audio files without copying tags.
  * Some minor changes.
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 16.5.0 (changes since 16.3.3):
  * Fix 'Too many open files' error on converting many files.
  * Fix Seeking in media player with MPV.
  * Fix Enable the 'Trim Duration' menu item only when a single
    file is selected.
  * Some minor changes.
- Fix CFLAGS in selene-fix-makefile.patch.
* Sat May  7 2016 sor.alexei@meowr.ru
- Update to version 16.3.3 (changes since 16.2.7):
  * Add options for copying audio and video track without
    re-encoding.
  * Use the first embedded subtitle track if an external subtitle
    file is not found.
  * Add support for encoding files with multiple audio/subtitle
    tracks.
  * Add support for encoding HEVC video in MKV.
  * Add libkate-tools as a dependency for encoding subtitles in
    OGG files.
  * Remove dependency on ffmpeg2theora tool which is unmaintained.
    Theora video will be encoded with ffmpeg/avconv.
  * Add option to set default language for files with multiple
    tracks.
  * Add option to keep or delete temporary files after successful
    encode.
  * Closing the progress window after a batch is finished will
    take user to main window instead of quitting the application.
  * Fix encoding mode being not set correctly for Vorbis.
  * Fix decimal numbers being not loaded correctly from preset file
    on non-English systems.
  * Fix 'Too many open files' error on converting many files.
  * Code cleanup and minor changes.
- Fix selene-fix-makefile.patch.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 16.2.7 (changes since 16.2.4):
  * Add new option for trimming audio and video files.
  * Add support for using MPV as the media player backend.
  * Add option to auto-crop and reset cropping values for multiple
    files on the batch edit window.
  * Add zoom and fullscreen options to media player.
- Switch from MPlayer to MPV.
- Rebase selene-fix-makefile.patch.
* Mon Feb 22 2016 sor.alexei@meowr.ru
- Update to 16.2.4 (changes since 16.2.1):
  * Playing the input file will run the media player independently
    without grabbing focus from other windows.
  * Show a progress dialog when files are added.
  * Add additional columns to the file list view and allow column to
    be re-ordered.
  * Add dialog for selecting list view columns.
  * Allow columns to be re-ordered from the column selection dialog.
  * Add new window for cropping video files.
  * Add option to run app in background in non-admin mode. This
    option was available earlier only in admin mode
  * Add new mplayer frontend for playing media files.
  * Fix output file being overwritten if it already exists.
    A number will be appended to the file name instead.
- Rebase selene-fix-makefile.patch.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 16.2.1 (changes since 2.6.1):
  * List of unsupported files will be displayed when files are
    added.
  * Round-up the CPU percentage in progress window title bar.
  * Hide the crop column while encoding is in-progress.
  * App settings: Allow user to enter backup path and output path.
  * App settings: Update checkboxes for selecting directories.
  * App settings: Add option to choose between 'ffmpeg' and 'avconv'.
  * App settings: Add option to select media player.
  * Add thumbnail image for audio files.
  * Add option to encode audio with FFmpeg's Native AAC encoder.
  * Add support for encoding with Fraunhofer FDK AAC encoder
    (aac-enc).
  * Add option to change AAC profile.
  * Removed the 'Preview Output' right-click option in file list.
  * Directories can be dragged and dropped on the main window to
    add files.
  * Update toolbar items for adding and removing files.
  * Show icon beside file name in list view.
  * Various minor changes.
- Rebase selene-fix-makefile.patch.
* Wed Nov 18 2015 sor.alexei@meowr.ru
- Update to 2.6.1:
  * Fix audio-video out-of-sync for H.264 video if framerate is fractional.
  * Fix incorrect icon displaying for 'About' button on toolbar.
  * Fix input file properties being not parsed correctly for some
    files. These files would give a 'format not supported' error
    when added to the input list.
  * Query only required properties when reading file info from disk.
  * Add list of 3rd party tools to the About\Credits dialog.
* Wed Oct 28 2015 sor.alexei@meowr.ru
- Update to 2.6.0.
* Mon Sep 14 2015 sor.alexei@meowr.ru
- Update to 2.5.8.
- Rebase selene-fix-makefile.patch.
- Remove selene-liststore.patch: fixed upstream.
* Wed Jul  1 2015 sor.alexei@meowr.ru
- Initial package.
